@@ -5,6 +5,7 @@ import test_SexpEnvironment
 import test_Sexp
 import test_SexpClosure
 import test_SexpVectorNumeric
+import test_Device
 
 import test_EmbeddedR
 #import test_EmbeddedR_multithreaded
@@ -17,18 +18,26 @@ def suite():
     suite_SexpClosure = test_SexpClosure.suite()
     suite_SexpVectorNumeric = test_SexpVectorNumeric.suite()
     suite_EmbeddedR = test_EmbeddedR.suite()
+    suite_Device = test_Device.suite()
     #suite_EmbeddedR_multithreaded = test_EmbeddedR_multithreaded.suite()
-    alltests = unittest.TestSuite([suite_SexpVector 
-                                   ,suite_SexpEnvironment 
-                                   ,suite_Sexp
-                                   ,suite_SexpClosure
-                                   ,suite_SexpVectorNumeric
-                                   ,suite_EmbeddedR
-    #                               suite_EmbeddedR_multithreaded
-                                  ])
+    alltests = unittest.TestSuite([
+        suite_EmbeddedR
+        ,suite_Sexp
+        ,suite_SexpVector 
+        ,suite_SexpEnvironment 
+        ,suite_SexpClosure
+        ,suite_SexpVectorNumeric
+        #,suite_Device
+        #,suite_EmbeddedR_multithreaded
+        ])
     return alltests
 
 def main():
     r = unittest.TestResult()
     suite().run(r)
     return r
+
+if __name__ == '__main__':    
+    tr = unittest.TextTestRunner(verbosity = 2)
+    suite = suite()
+    tr.run(suite)
